#
# spec file for package pplite
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libpplite5
Name:           pplite
Version:        0.12
Release:        2.2
Summary:        Computations with polyhedra
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://github.com/ezaffanella/PPLite/
Source:         https://github.com/ezaffanella/PPLite/raw/main/releases/%name-%version.tar.gz
Patch1:         0001-build-fix-build-error-with-flint-3.2.0.patch
BuildRequires:  pkgconfig(flint)
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel

%description
PPLite is a C++ library implementing the abstract domain of convex polyhedra,
to be used in tools for static analysis and verification.

%package -n %lname
Summary:        Library for computations with polyhedra
Group:          System/Libraries

%description -n %lname
PPLite is a C++ library implementing the abstract domain of convex polyhedra,
to be used in tools for static analysis and verification.

%package devel
Summary:        Headers and generators for pplite
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
PPLite is a C++ library implementing the abstract domain of convex polyhedra,
to be used in tools for static analysis and verification.
The main characteristics of PPLite:

  * Both closed and NNC rational convex polyhedra are supported.
  * Exact computations are based on FLINT.

%prep
%autosetup -p1

%build
%configure --disable-static
%make_build

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%check
if ! %make_build check; then
%ifnarch ppc64le
	exit 1
%endif
	:
fi

%ldconfig_scriptlets -n %lname

%files -n %lname
%license COPYING
%_libdir/libpplite.so.*

%files devel
%_bindir/pplite_lcdd
%_libdir/libpplite.so
%_includedir/pplite/

%changelog
* Fri Mar 14 2025 Jan Engelhardt <jengelh@inai.de>
- Add 0001-build-fix-build-error-with-flint-3.2.0.patch
* Sat Oct 26 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.12
  * The library no longer depends on the C++ interface of GMP
    (this change mainly affects classes ``pplite::Integer`` and
    ``pplite::Rational``).
  * The support for conditional thread safety is now enabled by
    default.
* Sun Nov 12 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.11
  * Adds a prototype implementation of the finite powerset of Poly
    elements (PSet).
  * Provides an efficiency-improved version of the F_Poly domain.
  * The finite powerset domain is now a class template:
    pre-generated instances, include finite sets of boxed polyhedra
    (P_Set) and finite sets of Cartesian factored boxed polyhedra
    (FP_Set).
  * Added support for the integral split operator.
  * Added new method `Index_Set get_unconstrained` to polyhedra
    domains, returning the set of unconstrained space dimensions.
* Mon Jun 21 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.7
  * This version also adds a C++ polymorphic interface allowing to
    experiment with several variants of the domain of convex
    polyhedra: Poly, U_Poly, F_Poly, UF_Poly and their XXX_Stats
    versions, computing timing information for abstract operators.
* Wed Sep 30 2020 Jan Engelhardt <jengelh@inai.de>
- Initial package (version 0.6) for build.opensuse.org
